#[repr(transparent)]pub struct SequenceRef {
body: BytesRef,
}Expand description
The SequenceRef type provides raw access to the octets which comprise a
DER-encoded SEQUENCE.
This is a zero-copy reference type which borrows from the input data.
Fields
body: BytesRefBody of the SEQUENCE.
Implementations
Sourceimpl SequenceRef
impl SequenceRef
Sourcefn from_bytes_ref(bytes_ref: &BytesRef) -> &Self
fn from_bytes_ref(bytes_ref: &BytesRef) -> &Self
Create a SequenceRef from a BytesRef.
Implemented as an inherent method to keep BytesRef out of the public API.